# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import utils_pb2 as utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bquery.proto\x12\x0bsumma.proto\x1a\x0butils.proto\"\'\n\x15TermFieldMapperConfig\x12\x0e\n\x06\x66ields\x18\x01 \x03(\t\"\x1d\n\x1bMatchQueryBooleanShouldMode\"2\n\x1bMatchQueryDisjuctionMaxMode\x12\x13\n\x0btie_breaker\x18\x01 \x01(\x02\"R\n\x14\x45xactMatchesPromoter\x12\x0c\n\x04slop\x18\x01 \x01(\r\x12\x12\n\x05\x62oost\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12\x0e\n\x06\x66ields\x18\x03 \x03(\tB\x08\n\x06_boost\"B\n\x12NerMatchesPromoter\x12\x12\n\x05\x62oost\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x0e\n\x06\x66ields\x18\x02 \x03(\tB\x08\n\x06_boost\"X\n\x10MorphologyConfig\x12&\n\x19\x64\x65rive_tenses_coefficient\x18\x01 \x01(\x02H\x00\x88\x01\x01\x42\x1c\n\x1a_derive_tenses_coefficient\"\xd3\x07\n\x11QueryParserConfig\x12G\n\rfield_aliases\x18\x01 \x03(\x0b\x32\x30.summa.proto.QueryParserConfig.FieldAliasesEntry\x12\x45\n\x0c\x66ield_boosts\x18\x02 \x03(\x0b\x32/.summa.proto.QueryParserConfig.FieldBoostsEntry\x12]\n\x19term_field_mapper_configs\x18\x03 \x03(\x0b\x32:.summa.proto.QueryParserConfig.TermFieldMapperConfigsEntry\x12\x12\n\nterm_limit\x18\x04 \x01(\r\x12\x16\n\x0e\x64\x65\x66\x61ult_fields\x18\x05 \x03(\t\x12G\n\x13\x62oolean_should_mode\x18\x06 \x01(\x0b\x32(.summa.proto.MatchQueryBooleanShouldModeH\x00\x12G\n\x13\x64isjuction_max_mode\x18\x07 \x01(\x0b\x32(.summa.proto.MatchQueryDisjuctionMaxModeH\x00\x12\x41\n\x16\x65xact_matches_promoter\x18\x08 \x01(\x0b\x32!.summa.proto.ExactMatchesPromoter\x12\x16\n\x0eremoved_fields\x18\t \x03(\t\x12Q\n\x12morphology_configs\x18\n \x03(\x0b\x32\x35.summa.proto.QueryParserConfig.MorphologyConfigsEntry\x12\x1b\n\x0equery_language\x18\x0b \x01(\tH\x01\x88\x01\x01\x1a\x33\n\x11\x46ieldAliasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x46ieldBoostsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x61\n\x1bTermFieldMapperConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".summa.proto.TermFieldMapperConfig:\x02\x38\x01\x1aW\n\x16MorphologyConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.summa.proto.MorphologyConfig:\x02\x38\x01\x42\x0e\n\x0c\x64\x65\x66\x61ult_modeB\x11\n\x0f_query_language\"_\n\x0eSearchResponse\x12\x14\n\x0c\x65lapsed_secs\x18\x01 \x01(\x01\x12\x37\n\x11\x63ollector_outputs\x18\x02 \x03(\x0b\x32\x1c.summa.proto.CollectorOutput\"\xad\x04\n\x05Query\x12,\n\x07\x62oolean\x18\x01 \x01(\x0b\x32\x19.summa.proto.BooleanQueryH\x00\x12(\n\x05match\x18\x02 \x01(\x0b\x32\x17.summa.proto.MatchQueryH\x00\x12(\n\x05regex\x18\x03 \x01(\x0b\x32\x17.summa.proto.RegexQueryH\x00\x12&\n\x04term\x18\x04 \x01(\x0b\x32\x16.summa.proto.TermQueryH\x00\x12*\n\x06phrase\x18\x05 \x01(\x0b\x32\x18.summa.proto.PhraseQueryH\x00\x12(\n\x05range\x18\x06 \x01(\x0b\x32\x17.summa.proto.RangeQueryH\x00\x12$\n\x03\x61ll\x18\x07 \x01(\x0b\x32\x15.summa.proto.AllQueryH\x00\x12\x38\n\x0emore_like_this\x18\x08 \x01(\x0b\x32\x1e.summa.proto.MoreLikeThisQueryH\x00\x12(\n\x05\x62oost\x18\t \x01(\x0b\x32\x17.summa.proto.BoostQueryH\x00\x12;\n\x0f\x64isjunction_max\x18\n \x01(\x0b\x32 .summa.proto.DisjunctionMaxQueryH\x00\x12(\n\x05\x65mpty\x18\x0b \x01(\x0b\x32\x17.summa.proto.EmptyQueryH\x00\x12*\n\x06\x65xists\x18\x0c \x01(\x0b\x32\x18.summa.proto.ExistsQueryH\x00\x42\x07\n\x05query\"\n\n\x08\x41llQuery\"\x0c\n\nEmptyQuery\">\n\nBoostQuery\x12!\n\x05query\x18\x01 \x01(\x0b\x32\x12.summa.proto.Query\x12\r\n\x05score\x18\x02 \x01(\t\"Q\n\x13\x44isjunctionMaxQuery\x12%\n\tdisjuncts\x18\x01 \x03(\x0b\x32\x12.summa.proto.Query\x12\x13\n\x0btie_breaker\x18\x02 \x01(\t\"\x91\x03\n\x11MoreLikeThisQuery\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\x12\x1e\n\x11min_doc_frequency\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x1e\n\x11max_doc_frequency\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x1f\n\x12min_term_frequency\x18\x04 \x01(\x04H\x02\x88\x01\x01\x12\x1c\n\x0fmax_query_terms\x18\x05 \x01(\x04H\x03\x88\x01\x01\x12\x1c\n\x0fmin_word_length\x18\x06 \x01(\x04H\x04\x88\x01\x01\x12\x1c\n\x0fmax_word_length\x18\x07 \x01(\x04H\x05\x88\x01\x01\x12\x12\n\x05\x62oost\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x12\n\nstop_words\x18\t \x03(\tB\x14\n\x12_min_doc_frequencyB\x14\n\x12_max_doc_frequencyB\x15\n\x13_min_term_frequencyB\x12\n\x10_max_query_termsB\x12\n\x10_min_word_lengthB\x12\n\x10_max_word_lengthB\x08\n\x06_boost\"9\n\x0bPhraseQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04slop\x18\x03 \x01(\r\">\n\nRangeQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.summa.proto.Range\"u\n\nMatchQuery\x12\r\n\x05value\x18\x01 \x01(\t\x12@\n\x13query_parser_config\x18\x02 \x01(\x0b\x32\x1e.summa.proto.QueryParserConfigH\x00\x88\x01\x01\x42\x16\n\x14_query_parser_config\"W\n\x0f\x42ooleanSubquery\x12!\n\x05occur\x18\x01 \x01(\x0e\x32\x12.summa.proto.Occur\x12!\n\x05query\x18\x02 \x01(\x0b\x32\x12.summa.proto.Query\"@\n\x0c\x42ooleanQuery\x12\x30\n\nsubqueries\x18\x01 \x03(\x0b\x32\x1c.summa.proto.BooleanSubquery\"*\n\nRegexQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\")\n\tTermQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1c\n\x0b\x45xistsQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\"\xa3\x01\n\x0b\x43ustomOrder\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x12.summa.proto.EmptyH\x00\x12#\n\x05\x63ount\x18\x02 \x01(\x0b\x32\x12.summa.proto.EmptyH\x00\x12\x19\n\x0fsub_aggregation\x18\x03 \x01(\tH\x00\x12!\n\x05order\x18\x04 \x01(\x0e\x32\x12.summa.proto.OrderB\x0e\n\x0corder_target\"*\n\x03Key\x12\r\n\x03str\x18\x01 \x01(\tH\x00\x12\r\n\x03\x66\x36\x34\x18\x02 \x01(\x01H\x00\x42\x05\n\x03key\"U\n\x05Range\x12\x0c\n\x04left\x18\x01 \x01(\t\x12\r\n\x05right\x18\x02 \x01(\t\x12\x16\n\x0eincluding_left\x18\x03 \x01(\x08\x12\x17\n\x0fincluding_right\x18\x04 \x01(\x08\":\n\x05Score\x12\x13\n\tf64_score\x18\x01 \x01(\x01H\x00\x12\x13\n\tu64_score\x18\x02 \x01(\x04H\x00\x42\x07\n\x05score\"%\n\tHighlight\x12\x0c\n\x04\x66rom\x18\x01 \x01(\r\x12\n\n\x02to\x18\x02 \x01(\r\"U\n\x07Snippet\x12\x10\n\x08\x66ragment\x18\x01 \x01(\x0c\x12*\n\nhighlights\x18\x02 \x03(\x0b\x32\x16.summa.proto.Highlight\x12\x0c\n\x04html\x18\x03 \x01(\t\"\xf0\x01\n\x0eScoredDocument\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\x12!\n\x05score\x18\x02 \x01(\x0b\x32\x12.summa.proto.Score\x12\x10\n\x08position\x18\x03 \x01(\r\x12;\n\x08snippets\x18\x04 \x03(\x0b\x32).summa.proto.ScoredDocument.SnippetsEntry\x12\x13\n\x0bindex_alias\x18\x05 \x01(\t\x1a\x45\n\rSnippetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.summa.proto.Snippet:\x02\x38\x01\";\n\x06Scorer\x12\x13\n\teval_expr\x18\x01 \x01(\tH\x00\x12\x12\n\x08order_by\x18\x02 \x01(\tH\x00\x42\x08\n\x06scorer\"\xa8\x02\n\tCollector\x12\x31\n\x08top_docs\x18\x01 \x01(\x0b\x32\x1d.summa.proto.TopDocsCollectorH\x00\x12\x45\n\x12reservoir_sampling\x18\x02 \x01(\x0b\x32\'.summa.proto.ReservoirSamplingCollectorH\x00\x12,\n\x05\x63ount\x18\x03 \x01(\x0b\x32\x1b.summa.proto.CountCollectorH\x00\x12,\n\x05\x66\x61\x63\x65t\x18\x04 \x01(\x0b\x32\x1b.summa.proto.FacetCollectorH\x00\x12\x38\n\x0b\x61ggregation\x18\x05 \x01(\x0b\x32!.summa.proto.AggregationCollectorH\x00\x42\x0b\n\tcollector\"\x89\x02\n\x0f\x43ollectorOutput\x12:\n\tdocuments\x18\x01 \x01(\x0b\x32%.summa.proto.DocumentsCollectorOutputH\x00\x12\x32\n\x05\x63ount\x18\x03 \x01(\x0b\x32!.summa.proto.CountCollectorOutputH\x00\x12\x32\n\x05\x66\x61\x63\x65t\x18\x04 \x01(\x0b\x32!.summa.proto.FacetCollectorOutputH\x00\x12>\n\x0b\x61ggregation\x18\x05 \x01(\x0b\x32\'.summa.proto.AggregationCollectorOutputH\x00\x42\x12\n\x10\x63ollector_output\"\x10\n\x0e\x43ountCollector\"%\n\x14\x43ountCollectorOutput\x12\r\n\x05\x63ount\x18\x01 \x01(\r\"/\n\x0e\x46\x61\x63\x65tCollector\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61\x63\x65ts\x18\x02 \x03(\t\"\x94\x01\n\x14\x46\x61\x63\x65tCollectorOutput\x12H\n\x0c\x66\x61\x63\x65t_counts\x18\x01 \x03(\x0b\x32\x32.summa.proto.FacetCollectorOutput.FacetCountsEntry\x1a\x32\n\x10\x46\x61\x63\x65tCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\";\n\x1aReservoirSamplingCollector\x12\r\n\x05limit\x18\x01 \x01(\r\x12\x0e\n\x06\x66ields\x18\x02 \x03(\t\"Z\n\x0eRandomDocument\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\x12!\n\x05score\x18\x02 \x01(\x0b\x32\x12.summa.proto.Score\x12\x13\n\x0bindex_alias\x18\x03 \x01(\t\"R\n ReservoirSamplingCollectorOutput\x12.\n\tdocuments\x18\x01 \x03(\x0b\x32\x1b.summa.proto.RandomDocument\"\x8a\x02\n\x10TopDocsCollector\x12\r\n\x05limit\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12(\n\x06scorer\x18\x03 \x01(\x0b\x32\x13.summa.proto.ScorerH\x00\x88\x01\x01\x12J\n\x0fsnippet_configs\x18\x04 \x03(\x0b\x32\x31.summa.proto.TopDocsCollector.SnippetConfigsEntry\x12\x0f\n\x07\x65xplain\x18\x05 \x01(\x08\x12\x0e\n\x06\x66ields\x18\x06 \x03(\t\x1a\x35\n\x13SnippetConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x42\t\n\x07_scorer\"c\n\x18\x44ocumentsCollectorOutput\x12\x35\n\x10scored_documents\x18\x01 \x03(\x0b\x32\x1b.summa.proto.ScoredDocument\x12\x10\n\x08has_next\x18\x02 \x01(\x08\",\n\x14\x41ggregationCollector\x12\x14\n\x0c\x61ggregations\x18\x01 \x01(\t\"9\n\x1a\x41ggregationCollectorOutput\x12\x1b\n\x13\x61ggregation_results\x18\x01 \x01(\t*+\n\x05Occur\x12\n\n\x06should\x10\x00\x12\x08\n\x04must\x10\x01\x12\x0c\n\x08must_not\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUERYPARSERCONFIG_FIELDALIASESENTRY._options = None
  _QUERYPARSERCONFIG_FIELDALIASESENTRY._serialized_options = b'8\001'
  _QUERYPARSERCONFIG_FIELDBOOSTSENTRY._options = None
  _QUERYPARSERCONFIG_FIELDBOOSTSENTRY._serialized_options = b'8\001'
  _QUERYPARSERCONFIG_TERMFIELDMAPPERCONFIGSENTRY._options = None
  _QUERYPARSERCONFIG_TERMFIELDMAPPERCONFIGSENTRY._serialized_options = b'8\001'
  _QUERYPARSERCONFIG_MORPHOLOGYCONFIGSENTRY._options = None
  _QUERYPARSERCONFIG_MORPHOLOGYCONFIGSENTRY._serialized_options = b'8\001'
  _SCOREDDOCUMENT_SNIPPETSENTRY._options = None
  _SCOREDDOCUMENT_SNIPPETSENTRY._serialized_options = b'8\001'
  _FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY._options = None
  _FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY._serialized_options = b'8\001'
  _TOPDOCSCOLLECTOR_SNIPPETCONFIGSENTRY._options = None
  _TOPDOCSCOLLECTOR_SNIPPETCONFIGSENTRY._serialized_options = b'8\001'
  _globals['_OCCUR']._serialized_start=5460
  _globals['_OCCUR']._serialized_end=5503
  _globals['_TERMFIELDMAPPERCONFIG']._serialized_start=41
  _globals['_TERMFIELDMAPPERCONFIG']._serialized_end=80
  _globals['_MATCHQUERYBOOLEANSHOULDMODE']._serialized_start=82
  _globals['_MATCHQUERYBOOLEANSHOULDMODE']._serialized_end=111
  _globals['_MATCHQUERYDISJUCTIONMAXMODE']._serialized_start=113
  _globals['_MATCHQUERYDISJUCTIONMAXMODE']._serialized_end=163
  _globals['_EXACTMATCHESPROMOTER']._serialized_start=165
  _globals['_EXACTMATCHESPROMOTER']._serialized_end=247
  _globals['_NERMATCHESPROMOTER']._serialized_start=249
  _globals['_NERMATCHESPROMOTER']._serialized_end=315
  _globals['_MORPHOLOGYCONFIG']._serialized_start=317
  _globals['_MORPHOLOGYCONFIG']._serialized_end=405
  _globals['_QUERYPARSERCONFIG']._serialized_start=408
  _globals['_QUERYPARSERCONFIG']._serialized_end=1387
  _globals['_QUERYPARSERCONFIG_FIELDALIASESENTRY']._serialized_start=1061
  _globals['_QUERYPARSERCONFIG_FIELDALIASESENTRY']._serialized_end=1112
  _globals['_QUERYPARSERCONFIG_FIELDBOOSTSENTRY']._serialized_start=1114
  _globals['_QUERYPARSERCONFIG_FIELDBOOSTSENTRY']._serialized_end=1164
  _globals['_QUERYPARSERCONFIG_TERMFIELDMAPPERCONFIGSENTRY']._serialized_start=1166
  _globals['_QUERYPARSERCONFIG_TERMFIELDMAPPERCONFIGSENTRY']._serialized_end=1263
  _globals['_QUERYPARSERCONFIG_MORPHOLOGYCONFIGSENTRY']._serialized_start=1265
  _globals['_QUERYPARSERCONFIG_MORPHOLOGYCONFIGSENTRY']._serialized_end=1352
  _globals['_SEARCHRESPONSE']._serialized_start=1389
  _globals['_SEARCHRESPONSE']._serialized_end=1484
  _globals['_QUERY']._serialized_start=1487
  _globals['_QUERY']._serialized_end=2044
  _globals['_ALLQUERY']._serialized_start=2046
  _globals['_ALLQUERY']._serialized_end=2056
  _globals['_EMPTYQUERY']._serialized_start=2058
  _globals['_EMPTYQUERY']._serialized_end=2070
  _globals['_BOOSTQUERY']._serialized_start=2072
  _globals['_BOOSTQUERY']._serialized_end=2134
  _globals['_DISJUNCTIONMAXQUERY']._serialized_start=2136
  _globals['_DISJUNCTIONMAXQUERY']._serialized_end=2217
  _globals['_MORELIKETHISQUERY']._serialized_start=2220
  _globals['_MORELIKETHISQUERY']._serialized_end=2621
  _globals['_PHRASEQUERY']._serialized_start=2623
  _globals['_PHRASEQUERY']._serialized_end=2680
  _globals['_RANGEQUERY']._serialized_start=2682
  _globals['_RANGEQUERY']._serialized_end=2744
  _globals['_MATCHQUERY']._serialized_start=2746
  _globals['_MATCHQUERY']._serialized_end=2863
  _globals['_BOOLEANSUBQUERY']._serialized_start=2865
  _globals['_BOOLEANSUBQUERY']._serialized_end=2952
  _globals['_BOOLEANQUERY']._serialized_start=2954
  _globals['_BOOLEANQUERY']._serialized_end=3018
  _globals['_REGEXQUERY']._serialized_start=3020
  _globals['_REGEXQUERY']._serialized_end=3062
  _globals['_TERMQUERY']._serialized_start=3064
  _globals['_TERMQUERY']._serialized_end=3105
  _globals['_EXISTSQUERY']._serialized_start=3107
  _globals['_EXISTSQUERY']._serialized_end=3135
  _globals['_CUSTOMORDER']._serialized_start=3138
  _globals['_CUSTOMORDER']._serialized_end=3301
  _globals['_KEY']._serialized_start=3303
  _globals['_KEY']._serialized_end=3345
  _globals['_RANGE']._serialized_start=3347
  _globals['_RANGE']._serialized_end=3432
  _globals['_SCORE']._serialized_start=3434
  _globals['_SCORE']._serialized_end=3492
  _globals['_HIGHLIGHT']._serialized_start=3494
  _globals['_HIGHLIGHT']._serialized_end=3531
  _globals['_SNIPPET']._serialized_start=3533
  _globals['_SNIPPET']._serialized_end=3618
  _globals['_SCOREDDOCUMENT']._serialized_start=3621
  _globals['_SCOREDDOCUMENT']._serialized_end=3861
  _globals['_SCOREDDOCUMENT_SNIPPETSENTRY']._serialized_start=3792
  _globals['_SCOREDDOCUMENT_SNIPPETSENTRY']._serialized_end=3861
  _globals['_SCORER']._serialized_start=3863
  _globals['_SCORER']._serialized_end=3922
  _globals['_COLLECTOR']._serialized_start=3925
  _globals['_COLLECTOR']._serialized_end=4221
  _globals['_COLLECTOROUTPUT']._serialized_start=4224
  _globals['_COLLECTOROUTPUT']._serialized_end=4489
  _globals['_COUNTCOLLECTOR']._serialized_start=4491
  _globals['_COUNTCOLLECTOR']._serialized_end=4507
  _globals['_COUNTCOLLECTOROUTPUT']._serialized_start=4509
  _globals['_COUNTCOLLECTOROUTPUT']._serialized_end=4546
  _globals['_FACETCOLLECTOR']._serialized_start=4548
  _globals['_FACETCOLLECTOR']._serialized_end=4595
  _globals['_FACETCOLLECTOROUTPUT']._serialized_start=4598
  _globals['_FACETCOLLECTOROUTPUT']._serialized_end=4746
  _globals['_FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY']._serialized_start=4696
  _globals['_FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY']._serialized_end=4746
  _globals['_RESERVOIRSAMPLINGCOLLECTOR']._serialized_start=4748
  _globals['_RESERVOIRSAMPLINGCOLLECTOR']._serialized_end=4807
  _globals['_RANDOMDOCUMENT']._serialized_start=4809
  _globals['_RANDOMDOCUMENT']._serialized_end=4899
  _globals['_RESERVOIRSAMPLINGCOLLECTOROUTPUT']._serialized_start=4901
  _globals['_RESERVOIRSAMPLINGCOLLECTOROUTPUT']._serialized_end=4983
  _globals['_TOPDOCSCOLLECTOR']._serialized_start=4986
  _globals['_TOPDOCSCOLLECTOR']._serialized_end=5252
  _globals['_TOPDOCSCOLLECTOR_SNIPPETCONFIGSENTRY']._serialized_start=5188
  _globals['_TOPDOCSCOLLECTOR_SNIPPETCONFIGSENTRY']._serialized_end=5241
  _globals['_DOCUMENTSCOLLECTOROUTPUT']._serialized_start=5254
  _globals['_DOCUMENTSCOLLECTOROUTPUT']._serialized_end=5353
  _globals['_AGGREGATIONCOLLECTOR']._serialized_start=5355
  _globals['_AGGREGATIONCOLLECTOR']._serialized_end=5399
  _globals['_AGGREGATIONCOLLECTOROUTPUT']._serialized_start=5401
  _globals['_AGGREGATIONCOLLECTOROUTPUT']._serialized_end=5458
# @@protoc_insertion_point(module_scope)
