# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: unixfs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cunixfs.proto\x12\x06unixfs\"\x9b\x02\n\x04\x44\x61ta\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.unixfs.Data.DataType\x12\x11\n\x04\x64\x61ta\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x12\x15\n\x08\x66ilesize\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x12\n\nblocksizes\x18\x04 \x03(\x04\x12\x15\n\x08hashType\x18\x05 \x01(\x04H\x02\x88\x01\x01\x12\x13\n\x06\x66\x61nout\x18\x06 \x01(\x04H\x03\x88\x01\x01\"V\n\x08\x44\x61taType\x12\x07\n\x03Raw\x10\x00\x12\r\n\tDirectory\x10\x01\x12\x08\n\x04\x46ile\x10\x02\x12\x0c\n\x08Metadata\x10\x03\x12\x0b\n\x07Symlink\x10\x04\x12\r\n\tHAMTShard\x10\x05\x42\x07\n\x05_dataB\x0b\n\t_filesizeB\x0b\n\t_hashTypeB\t\n\x07_fanout\".\n\x08Metadata\x12\x15\n\x08MimeType\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_MimeTypeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'unixfs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DATA']._serialized_start=25
  _globals['_DATA']._serialized_end=308
  _globals['_DATA_DATATYPE']._serialized_start=176
  _globals['_DATA_DATATYPE']._serialized_end=262
  _globals['_METADATA']._serialized_start=310
  _globals['_METADATA']._serialized_end=356
# @@protoc_insertion_point(module_scope)
